==> IceWarpServer-10.0.8_RHEL5.tar.gz: html/webmail/client/inc/frm_im_addgtw.js <==
_me = frm_im_addgtw.prototype;
function frm_im_addgtw(){};

/**
 * @brief
 */
_me.__constructor = function(xmpp,jid,sGroup) {
	var me = this;

	this._size(300,300,true);

	this._title('IM::ADD_GATEWAY');

	this.__obj = [];

	// Create 'OK' button
	this._create('btn_ok', 'obj_button', 'footer');
	this.btn_ok._value('FORM_BUTTONS::OK');
	this.btn_ok._tabindex(5000);
	this.btn_ok._disabled(true);
	this.btn_ok._onclick = function() {
		var aData = {};
		//Collect data
        if(me.__obj.length)
			for(var i in me.__obj)
	            aData[me.__obj[i].name.toUpperCase()] = [{VALUE:me[me.__obj[i].id]._value()}];

		xmpp.gateway_registr(aData,jid,[me,'__add']);
	};

	// Create 'CANCEL' button
	this._create('btn_cancel', 'obj_button', 'footer');
	this.btn_cancel._value('FORM_BUTTONS::CANCEL');
	this.btn_cancel._tabindex(5001);
	this.btn_cancel._onclick = function() {
		me._destruct();
	};

	xmpp.gateway_registr('',jid,[this,'__registr']);
};

/*
[QUERY]
.. [0]
.... [USERNAME]
...... [0]
.... [PASSWORD]
...... [0]
.... [INSTRUCTIONS]
...... [0]
........ [VALUE](string) = Please enter your username and password
.... [ATTRIBUTES]
...... [XMLNS](string) = jabber:iq:register
[ATTRIBUTES]
.. [ID](string) = 799421682215594201244709021710
.. [FROM](string) = 007guard.com
.. [TO](string) = admin@merakdemo.com/Webmail
.. [TYPE](string) = result
*/
_me.__registr = function(aData){
	if (aData.ATTRIBUTES.TYPE == 'result'){
		if (aData.QUERY[0].REGISTERED){
			this._create('info', 'obj_label', 'header');
			this.info._value(getLang('IM::REGISTRED'));
		}
		else{
			for (var i in aData.QUERY[0]){
				if (i == 'ATTRIBUTES')
				    continue;
				else
				if (i == 'INSTRUCTIONS'){
					this._create('info', 'obj_label', 'header');
					this.info._value(aData.QUERY[0].INSTRUCTIONS[0].VALUE);
				}
				else
					this.__obj.push({id:'X_'+this.__obj.length,name:i.toLowerCase(),type:i=='PASSWORD'?'obj_password':'obj_input'});
			}

			if (this.__obj.length){
				this._draw('frm_im_addgtw','main',{'form':this.__obj});
				this[this.__obj[0].id]._focus();
			}
			
			this.btn_ok._disabled(false);
		}
	}
	else
	    this._destruct();
};

_me.__add = function(aData){
	if (aData && aData.ATTRIBUTES && aData.ATTRIBUTES.TYPE == 'result')
		this._destruct();
	//Error?
	else
        gui._create('alert','frm_alert','','','','','IM::ERROR_REGISTR');
};

==> IceWarpServer-10.1.4_RHEL5.tar.gz: html/webmail/client/inc/frm_im_addgtw.js <==
_me = frm_im_addgtw.prototype;
function frm_im_addgtw(){};

/**
 * @brief
 */
_me.__constructor = function(xmpp,jid,sGroup) {
	var me = this;

	this._size(300,300,true);

	this._title('IM::ADD_SERVICE');

	this.__obj = [];

	// Create 'OK' button
	this._create('btn_ok', 'obj_button', 'footer');
	this.btn_ok._value('FORM_BUTTONS::OK');
	this.btn_ok._disabled(true);
	this.btn_ok._onclick = function() {
		var aData = {};
		//Collect data
        if(me.__obj.length)
			for(var i in me.__obj)
	            aData[me.__obj[i].name.toUpperCase()] = [{VALUE:me[me.__obj[i].id]._value()}];

		xmpp.gateway_registr(aData,jid,[me,'__add']);
	};

	// Create 'CANCEL' button
	this._create('btn_cancel', 'obj_button', 'footer');
	this.btn_cancel._value('FORM_BUTTONS::CANCEL');
	this.btn_cancel._onclick = function() {
		me._destruct();
	};

	xmpp.gateway_registr('',jid,[this,'__registr']);
};

/*
[QUERY]
.. [0]
.... [USERNAME]
...... [0]
.... [PASSWORD]
...... [0]
.... [INSTRUCTIONS]
...... [0]
........ [VALUE](string) = Please enter your username and password
.... [ATTRIBUTES]
...... [XMLNS](string) = jabber:iq:register
[ATTRIBUTES]
.. [ID](string) = 799421682215594201244709021710
.. [FROM](string) = 007guard.com
.. [TO](string) = admin@merakdemo.com/Webmail
.. [TYPE](string) = result
*/
_me.__registr = function(aData){
	if (aData.ATTRIBUTES.TYPE == 'result'){
		if (aData.QUERY[0].REGISTERED){
			this._create('info', 'obj_label', 'header');
			this.info._value(getLang('IM::REGISTRED'));
		}
		else{
			for (var i in aData.QUERY[0])
				if (i == 'ATTRIBUTES')
				    continue;
				else
				if (i == 'INSTRUCTIONS'){
					this._create('info', 'obj_label', 'header');
					this.info._value(aData.QUERY[0].INSTRUCTIONS[0].VALUE);
				}
				else
					this.__obj.push({id:'X_'+this.__obj.length,name:i.toLowerCase(),type:i=='PASSWORD'?'obj_password':'obj_input'});

			if (this.__obj.length){
				this._draw('frm_im_addgtw','main',{'form':this.__obj});
				this[this.__obj[0].id]._focus();
			}

			this.btn_ok._disabled(false);
		}
	}
	else
	    this._destruct();
};

_me.__add = function(aData){
	if (aData && aData.ATTRIBUTES && aData.ATTRIBUTES.TYPE == 'result')
		this._destruct();
	//Error?
	else
        gui._create('alert','frm_alert','','','','','IM::ERROR_REGISTR');
};
